"use strict";
// *****************************************************************************
// Copyright (C) 2021 logi.cals GmbH, EclipseSource and others.
//
// This program and the accompanying materials are made available under the
// terms of the Eclipse Public License v. 2.0 which is available at
// http://www.eclipse.org/legal/epl-2.0.
//
// This Source Code may also be made available under the following Secondary
// Licenses when the conditions for such availability set forth in the Eclipse
// Public License v. 2.0 are satisfied: GNU General Public License, version 2
// with the GNU Classpath Exception which is available at
// https://www.gnu.org/software/classpath/license.html.
//
// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
// *****************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@playwright/test");
const theia_app_1 = require("../theia-app");
const theia_explorer_view_1 = require("../theia-explorer-view");
const theia_workspace_1 = require("../theia-workspace");
const theia_fixture_1 = require("./fixtures/theia-fixture");
let app;
let explorer;
theia_fixture_1.default.describe('Theia Explorer View', () => {
    theia_fixture_1.default.beforeAll(async () => {
        const ws = new theia_workspace_1.TheiaWorkspace(['src/tests/resources/sample-files1']);
        app = await theia_app_1.TheiaApp.load(theia_fixture_1.page, ws);
        explorer = await app.openView(theia_explorer_view_1.TheiaExplorerView);
    });
    (0, theia_fixture_1.default)('should be visible and active after being opened', async () => {
        (0, test_1.expect)(await explorer.isTabVisible()).toBe(true);
        (0, test_1.expect)(await explorer.isDisplayed()).toBe(true);
        (0, test_1.expect)(await explorer.isActive()).toBe(true);
    });
    (0, theia_fixture_1.default)("should be opened at the left and have the title 'Explorer'", async () => {
        (0, test_1.expect)(await explorer.isInSidePanel()).toBe(true);
        (0, test_1.expect)(await explorer.side()).toBe('left');
        (0, test_1.expect)(await explorer.title()).toBe('Explorer');
    });
    (0, theia_fixture_1.default)('should be possible to close and reopen it', async () => {
        await explorer.close();
        (0, test_1.expect)(await explorer.isTabVisible()).toBe(false);
        explorer = await app.openView(theia_explorer_view_1.TheiaExplorerView);
        (0, test_1.expect)(await explorer.isTabVisible()).toBe(true);
        (0, test_1.expect)(await explorer.isDisplayed()).toBe(true);
        (0, test_1.expect)(await explorer.isActive()).toBe(true);
    });
    (0, theia_fixture_1.default)('should show one folder named "sampleFolder" and one file named "sample.txt"', async () => {
        await explorer.selectTreeNode('sampleFolder');
        (0, test_1.expect)(await explorer.isTreeNodeSelected('sampleFolder')).toBe(true);
        const fileStatElements = await explorer.visibleFileStatNodes(theia_explorer_view_1.DOT_FILES_FILTER);
        (0, test_1.expect)(fileStatElements.length).toBe(2);
        let file;
        let folder;
        if (await fileStatElements[0].isFolder()) {
            folder = fileStatElements[0];
            file = fileStatElements[1];
        }
        else {
            folder = fileStatElements[1];
            file = fileStatElements[0];
        }
        (0, test_1.expect)(await folder.label()).toBe('sampleFolder');
        (0, test_1.expect)(await folder.isFile()).toBe(false);
        (0, test_1.expect)(await folder.isFolder()).toBe(true);
        (0, test_1.expect)(await file.label()).toBe('sample.txt');
        (0, test_1.expect)(await file.isFolder()).toBe(false);
        (0, test_1.expect)(await file.isFile()).toBe(true);
    });
    (0, theia_fixture_1.default)('should provide file stat node by single path fragment "sample.txt"', async () => {
        const file = await explorer.getFileStatNodeByLabel('sample.txt');
        (0, test_1.expect)(await file.label()).toBe('sample.txt');
        (0, test_1.expect)(await file.isFolder()).toBe(false);
        (0, test_1.expect)(await file.isFile()).toBe(true);
    });
    (0, theia_fixture_1.default)('should provide file stat nodes that can define whether they are collapsed or not and that can be expanded', async () => {
        const file = await explorer.getFileStatNodeByLabel('sample.txt');
        (0, test_1.expect)(await file.isCollapsed()).toBe(false);
        const folder = await explorer.getFileStatNodeByLabel('sampleFolder');
        (0, test_1.expect)(await folder.isCollapsed()).toBe(true);
        await folder.expand();
        (0, test_1.expect)(await folder.isCollapsed()).toBe(false);
    });
    (0, theia_fixture_1.default)('should provide file stat node by path "sampleFolder/sampleFolder1/sampleFolder1-1/sampleFile1-1-1.txt"', async () => {
        const file = await explorer.fileStatNode('sampleFolder/sampleFolder1/sampleFolder1-1/sampleFile1-1-1.txt');
        if (!file) {
            throw Error('File stat node could not be retrieved by path');
        }
        (0, test_1.expect)(await file.label()).toBe('sampleFile1-1-1.txt');
    });
    (0, theia_fixture_1.default)('should open context menu on "sample.txt"', async () => {
        const file = await explorer.getFileStatNodeByLabel('sample.txt');
        const menu = await file.openContextMenu();
        (0, test_1.expect)(await menu.isOpen()).toBe(true);
        const menuItems = await menu.visibleMenuItems();
        (0, test_1.expect)(menuItems).toContain('Open');
        (0, test_1.expect)(menuItems).toContain('Delete');
        (0, test_1.expect)(menuItems).toContain('Download');
        await menu.close();
        (0, test_1.expect)(await menu.isOpen()).toBe(false);
    });
    (0, theia_fixture_1.default)('should rename "sample.txt"', async () => {
        await explorer.renameNode('sample.txt', 'sample-new.txt');
        (0, test_1.expect)(await explorer.existsFileNode('sample-new.txt')).toBe(true);
        await explorer.renameNode('sample-new.txt', 'sample.txt');
        (0, test_1.expect)(await explorer.existsFileNode('sample.txt')).toBe(true);
    });
});
//# sourceMappingURL=theia-explorer-view.test.js.map